pub struct DisassociateIpGroups { /* private fields */ }Expand description
Fluent builder constructing a request to DisassociateIpGroups.
Disassociates the specified IP access control group from the specified directory.
Implementations
sourceimpl DisassociateIpGroups
impl DisassociateIpGroups
sourcepub async fn send(
self
) -> Result<DisassociateIpGroupsOutput, SdkError<DisassociateIpGroupsError>>
pub async fn send(
self
) -> Result<DisassociateIpGroupsOutput, SdkError<DisassociateIpGroupsError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn directory_id(self, input: impl Into<String>) -> Self
pub fn directory_id(self, input: impl Into<String>) -> Self
The identifier of the directory.
sourcepub fn set_directory_id(self, input: Option<String>) -> Self
pub fn set_directory_id(self, input: Option<String>) -> Self
The identifier of the directory.
sourcepub fn group_ids(self, input: impl Into<String>) -> Self
pub fn group_ids(self, input: impl Into<String>) -> Self
Appends an item to GroupIds.
To override the contents of this collection use set_group_ids.
The identifiers of one or more IP access control groups.
sourcepub fn set_group_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_group_ids(self, input: Option<Vec<String>>) -> Self
The identifiers of one or more IP access control groups.