#[non_exhaustive]
pub enum RegisterWorkspaceDirectoryErrorKind {
AccessDeniedException(AccessDeniedException),
InvalidParameterValuesException(InvalidParameterValuesException),
InvalidResourceStateException(InvalidResourceStateException),
OperationNotSupportedException(OperationNotSupportedException),
ResourceLimitExceededException(ResourceLimitExceededException),
ResourceNotFoundException(ResourceNotFoundException),
UnsupportedNetworkConfigurationException(UnsupportedNetworkConfigurationException),
WorkspacesDefaultRoleNotFoundException(WorkspacesDefaultRoleNotFoundException),
Unhandled(Unhandled),
}Expand description
Types of errors that can occur for the RegisterWorkspaceDirectory operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
The user is not authorized to access a resource.
InvalidParameterValuesException(InvalidParameterValuesException)
One or more parameter values are not valid.
InvalidResourceStateException(InvalidResourceStateException)
The state of the resource is not valid for this operation.
OperationNotSupportedException(OperationNotSupportedException)
This operation is not supported.
ResourceLimitExceededException(ResourceLimitExceededException)
Your resource limits have been exceeded.
ResourceNotFoundException(ResourceNotFoundException)
The resource could not be found.
UnsupportedNetworkConfigurationException(UnsupportedNetworkConfigurationException)
The configuration of this network is not supported for this operation, or your network configuration conflicts with the Amazon WorkSpaces management network IP range. For more information, see Configure a VPC for Amazon WorkSpaces.
WorkspacesDefaultRoleNotFoundException(WorkspacesDefaultRoleNotFoundException)
The workspaces_DefaultRole role could not be found. If this is the first time you are registering a directory, you will need to create the workspaces_DefaultRole role before you can register a directory. For more information, see Creating the workspaces_DefaultRole Role.
Unhandled(Unhandled)
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
When logging an error from the SDK, it is recommended that you either wrap the error in
DisplayErrorContext, use another
error reporter library that visits the error’s cause/source chain, or call
Error::source for more details about the underlying cause.