Struct aws_sdk_workspaces::input::create_ip_group_input::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for CreateIpGroupInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn group_name(self, input: impl Into<String>) -> Self
pub fn group_name(self, input: impl Into<String>) -> Self
The name of the group.
sourcepub fn set_group_name(self, input: Option<String>) -> Self
pub fn set_group_name(self, input: Option<String>) -> Self
The name of the group.
sourcepub fn group_desc(self, input: impl Into<String>) -> Self
pub fn group_desc(self, input: impl Into<String>) -> Self
The description of the group.
sourcepub fn set_group_desc(self, input: Option<String>) -> Self
pub fn set_group_desc(self, input: Option<String>) -> Self
The description of the group.
sourcepub fn user_rules(self, input: IpRuleItem) -> Self
pub fn user_rules(self, input: IpRuleItem) -> Self
Appends an item to user_rules.
To override the contents of this collection use set_user_rules.
The rules to add to the group.
sourcepub fn set_user_rules(self, input: Option<Vec<IpRuleItem>>) -> Self
pub fn set_user_rules(self, input: Option<Vec<IpRuleItem>>) -> Self
The rules to add to the group.
Appends an item to tags.
To override the contents of this collection use set_tags.
The tags. Each WorkSpaces resource can have a maximum of 50 tags.
The tags. Each WorkSpaces resource can have a maximum of 50 tags.
sourcepub fn build(self) -> Result<CreateIpGroupInput, BuildError>
pub fn build(self) -> Result<CreateIpGroupInput, BuildError>
Consumes the builder and constructs a CreateIpGroupInput.