pub struct Builder { /* private fields */ }Expand description
A builder for DescribeClientPropertiesInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn resource_ids(self, input: impl Into<String>) -> Self
pub fn resource_ids(self, input: impl Into<String>) -> Self
Appends an item to resource_ids.
To override the contents of this collection use set_resource_ids.
The resource identifier, in the form of directory IDs.
sourcepub fn set_resource_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_resource_ids(self, input: Option<Vec<String>>) -> Self
The resource identifier, in the form of directory IDs.
sourcepub fn build(self) -> Result<DescribeClientPropertiesInput, BuildError>
pub fn build(self) -> Result<DescribeClientPropertiesInput, BuildError>
Consumes the builder and constructs a DescribeClientPropertiesInput.