Struct aws_sdk_workspaces::input::describe_ip_groups_input::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for DescribeIpGroupsInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn group_ids(self, input: impl Into<String>) -> Self
pub fn group_ids(self, input: impl Into<String>) -> Self
Appends an item to group_ids.
To override the contents of this collection use set_group_ids.
The identifiers of one or more IP access control groups.
sourcepub fn set_group_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_group_ids(self, input: Option<Vec<String>>) -> Self
The identifiers of one or more IP access control groups.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results.
sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of items to return.
sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of items to return.
sourcepub fn build(self) -> Result<DescribeIpGroupsInput, BuildError>
pub fn build(self) -> Result<DescribeIpGroupsInput, BuildError>
Consumes the builder and constructs a DescribeIpGroupsInput.