Struct aws_sdk_workspaces::input::describe_workspaces_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DescribeWorkspacesInput
Implementations
Appends an item to workspace_ids.
To override the contents of this collection use set_workspace_ids.
The identifiers of the WorkSpaces. You cannot combine this parameter with any other filter.
Because the CreateWorkspaces operation is asynchronous, the identifier it returns is not immediately available. If you immediately call DescribeWorkspaces with this identifier, no information is returned.
The identifiers of the WorkSpaces. You cannot combine this parameter with any other filter.
Because the CreateWorkspaces operation is asynchronous, the identifier it returns is not immediately available. If you immediately call DescribeWorkspaces with this identifier, no information is returned.
The identifier of the directory. In addition, you can optionally specify a specific
directory user (see UserName). You cannot combine this parameter with any
other filter.
The identifier of the directory. In addition, you can optionally specify a specific
directory user (see UserName). You cannot combine this parameter with any
other filter.
The name of the directory user. You must specify this parameter with
DirectoryId.
The name of the directory user. You must specify this parameter with
DirectoryId.
The identifier of the bundle. All WorkSpaces that are created from this bundle are retrieved. You cannot combine this parameter with any other filter.
The identifier of the bundle. All WorkSpaces that are created from this bundle are retrieved. You cannot combine this parameter with any other filter.
If you received a NextToken from a previous call that was paginated,
provide this token to receive the next set of results.
If you received a NextToken from a previous call that was paginated,
provide this token to receive the next set of results.
Consumes the builder and constructs a DescribeWorkspacesInput