#[non_exhaustive]pub struct DeregisterWorkspaceDirectoryInput { /* private fields */ }Implementations
sourceimpl DeregisterWorkspaceDirectoryInput
impl DeregisterWorkspaceDirectoryInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DeregisterWorkspaceDirectory, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DeregisterWorkspaceDirectory, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DeregisterWorkspaceDirectory>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DeregisterWorkspaceDirectoryInput.
sourceimpl DeregisterWorkspaceDirectoryInput
impl DeregisterWorkspaceDirectoryInput
sourcepub fn directory_id(&self) -> Option<&str>
pub fn directory_id(&self) -> Option<&str>
The identifier of the directory. If any WorkSpaces are registered to this directory, you must remove them before you deregister the directory, or you will receive an OperationNotSupportedException error.