Struct aws_sdk_workspaces::input::DescribeIpGroupsInput
source · #[non_exhaustive]pub struct DescribeIpGroupsInput { /* private fields */ }Implementations
sourceimpl DescribeIpGroupsInput
impl DescribeIpGroupsInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeIpGroups, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeIpGroups, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DescribeIpGroups>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeIpGroupsInput.
sourceimpl DescribeIpGroupsInput
impl DescribeIpGroupsInput
sourcepub fn group_ids(&self) -> Option<&[String]>
pub fn group_ids(&self) -> Option<&[String]>
The identifiers of one or more IP access control groups.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results.
sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of items to return.