#[non_exhaustive]pub struct DescribeWorkspaceBundlesInput { /* private fields */ }Implementations
sourceimpl DescribeWorkspaceBundlesInput
impl DescribeWorkspaceBundlesInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeWorkspaceBundles, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeWorkspaceBundles, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DescribeWorkspaceBundles>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeWorkspaceBundlesInput.
sourceimpl DescribeWorkspaceBundlesInput
impl DescribeWorkspaceBundlesInput
sourcepub fn bundle_ids(&self) -> Option<&[String]>
pub fn bundle_ids(&self) -> Option<&[String]>
The identifiers of the bundles. You cannot combine this parameter with any other filter.
sourcepub fn owner(&self) -> Option<&str>
pub fn owner(&self) -> Option<&str>
The owner of the bundles. You cannot combine this parameter with any other filter.
To describe the bundles provided by Amazon Web Services, specify AMAZON. To describe the bundles that belong to your account, don't specify a value.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token for the next set of results. (You received this token from a previous call.)