#[non_exhaustive]pub struct DescribeWorkspaceDirectoriesInput { /* private fields */ }Implementations
sourceimpl DescribeWorkspaceDirectoriesInput
impl DescribeWorkspaceDirectoriesInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeWorkspaceDirectories, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeWorkspaceDirectories, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DescribeWorkspaceDirectories>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeWorkspaceDirectoriesInput.
sourceimpl DescribeWorkspaceDirectoriesInput
impl DescribeWorkspaceDirectoriesInput
sourcepub fn directory_ids(&self) -> Option<&[String]>
pub fn directory_ids(&self) -> Option<&[String]>
The identifiers of the directories. If the value is null, all directories are retrieved.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results.