Struct aws_sdk_workspaces::input::DescribeWorkspacesInput
source · #[non_exhaustive]pub struct DescribeWorkspacesInput { /* private fields */ }Implementations
sourceimpl DescribeWorkspacesInput
impl DescribeWorkspacesInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeWorkspaces, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeWorkspaces, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<DescribeWorkspaces>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeWorkspacesInput.
sourceimpl DescribeWorkspacesInput
impl DescribeWorkspacesInput
sourcepub fn workspace_ids(&self) -> Option<&[String]>
pub fn workspace_ids(&self) -> Option<&[String]>
The identifiers of the WorkSpaces. You cannot combine this parameter with any other filter.
Because the CreateWorkspaces operation is asynchronous, the identifier it returns is not immediately available. If you immediately call DescribeWorkspaces with this identifier, no information is returned.
sourcepub fn directory_id(&self) -> Option<&str>
pub fn directory_id(&self) -> Option<&str>
The identifier of the directory. In addition, you can optionally specify a specific directory user (see UserName). You cannot combine this parameter with any other filter.
sourcepub fn user_name(&self) -> Option<&str>
pub fn user_name(&self) -> Option<&str>
The name of the directory user. You must specify this parameter with DirectoryId.
sourcepub fn bundle_id(&self) -> Option<&str>
pub fn bundle_id(&self) -> Option<&str>
The identifier of the bundle. All WorkSpaces that are created from this bundle are retrieved. You cannot combine this parameter with any other filter.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results.