Struct aws_sdk_workspaces::input::UpdateConnectionAliasPermissionInput [−][src]
#[non_exhaustive]pub struct UpdateConnectionAliasPermissionInput {
pub alias_id: Option<String>,
pub connection_alias_permission: Option<ConnectionAliasPermission>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.alias_id: Option<String>The identifier of the connection alias that you want to update permissions for.
connection_alias_permission: Option<ConnectionAliasPermission>Indicates whether to share or unshare the connection alias with the specified Amazon Web Services account.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateConnectionAliasPermission, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateConnectionAliasPermission, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateConnectionAliasPermission>
Creates a new builder-style object to manufacture UpdateConnectionAliasPermissionInput