pub struct Builder { /* private fields */ }Expand description
A builder for CertificateBasedAuthProperties.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn status(self, input: CertificateBasedAuthStatusEnum) -> Self
pub fn status(self, input: CertificateBasedAuthStatusEnum) -> Self
The status of the certificate-based authentication properties.
sourcepub fn set_status(self, input: Option<CertificateBasedAuthStatusEnum>) -> Self
pub fn set_status(self, input: Option<CertificateBasedAuthStatusEnum>) -> Self
The status of the certificate-based authentication properties.
The Amazon Resource Name (ARN) of the Amazon Web Services Certificate Manager Private CA resource.
The Amazon Resource Name (ARN) of the Amazon Web Services Certificate Manager Private CA resource.
sourcepub fn build(self) -> CertificateBasedAuthProperties
pub fn build(self) -> CertificateBasedAuthProperties
Consumes the builder and constructs a CertificateBasedAuthProperties.