pub struct Builder { /* private fields */ }Expand description
A builder for ConnectionAliasAssociation.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn association_status(self, input: AssociationStatus) -> Self
pub fn association_status(self, input: AssociationStatus) -> Self
The association status of the connection alias.
sourcepub fn set_association_status(self, input: Option<AssociationStatus>) -> Self
pub fn set_association_status(self, input: Option<AssociationStatus>) -> Self
The association status of the connection alias.
sourcepub fn associated_account_id(self, input: impl Into<String>) -> Self
pub fn associated_account_id(self, input: impl Into<String>) -> Self
The identifier of the Amazon Web Services account that associated the connection alias with a directory.
sourcepub fn set_associated_account_id(self, input: Option<String>) -> Self
pub fn set_associated_account_id(self, input: Option<String>) -> Self
The identifier of the Amazon Web Services account that associated the connection alias with a directory.
sourcepub fn resource_id(self, input: impl Into<String>) -> Self
pub fn resource_id(self, input: impl Into<String>) -> Self
The identifier of the directory associated with a connection alias.
sourcepub fn set_resource_id(self, input: Option<String>) -> Self
pub fn set_resource_id(self, input: Option<String>) -> Self
The identifier of the directory associated with a connection alias.
sourcepub fn connection_identifier(self, input: impl Into<String>) -> Self
pub fn connection_identifier(self, input: impl Into<String>) -> Self
The identifier of the connection alias association. You use the connection identifier in the DNS TXT record when you're configuring your DNS routing policies.
sourcepub fn set_connection_identifier(self, input: Option<String>) -> Self
pub fn set_connection_identifier(self, input: Option<String>) -> Self
The identifier of the connection alias association. You use the connection identifier in the DNS TXT record when you're configuring your DNS routing policies.
sourcepub fn build(self) -> ConnectionAliasAssociation
pub fn build(self) -> ConnectionAliasAssociation
Consumes the builder and constructs a ConnectionAliasAssociation.