#[non_exhaustive]pub struct CertificateBasedAuthProperties { /* private fields */ }Expand description
Describes the properties of the certificate-based authentication you want to use with your WorkSpaces.
Implementations
sourceimpl CertificateBasedAuthProperties
impl CertificateBasedAuthProperties
sourcepub fn status(&self) -> Option<&CertificateBasedAuthStatusEnum>
pub fn status(&self) -> Option<&CertificateBasedAuthStatusEnum>
The status of the certificate-based authentication properties.
The Amazon Resource Name (ARN) of the Amazon Web Services Certificate Manager Private CA resource.
sourceimpl CertificateBasedAuthProperties
impl CertificateBasedAuthProperties
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture CertificateBasedAuthProperties.