#[non_exhaustive]pub struct DefaultWorkspaceCreationProperties { /* private fields */ }Expand description
Describes the default values that are used to create WorkSpaces. For more information, see Update Directory Details for Your WorkSpaces.
Implementations
sourceimpl DefaultWorkspaceCreationProperties
impl DefaultWorkspaceCreationProperties
sourcepub fn enable_work_docs(&self) -> Option<bool>
pub fn enable_work_docs(&self) -> Option<bool>
Specifies whether the directory is enabled for Amazon WorkDocs.
sourcepub fn enable_internet_access(&self) -> Option<bool>
pub fn enable_internet_access(&self) -> Option<bool>
Specifies whether to automatically assign an Elastic public IP address to WorkSpaces in this directory by default. If enabled, the Elastic public IP address allows outbound internet access from your WorkSpaces when you’re using an internet gateway in the Amazon VPC in which your WorkSpaces are located. If you're using a Network Address Translation (NAT) gateway for outbound internet access from your VPC, or if your WorkSpaces are in public subnets and you manually assign them Elastic IP addresses, you should disable this setting. This setting applies to new WorkSpaces that you launch or to existing WorkSpaces that you rebuild. For more information, see Configure a VPC for Amazon WorkSpaces.
sourcepub fn default_ou(&self) -> Option<&str>
pub fn default_ou(&self) -> Option<&str>
The organizational unit (OU) in the directory for the WorkSpace machine accounts.
sourcepub fn custom_security_group_id(&self) -> Option<&str>
pub fn custom_security_group_id(&self) -> Option<&str>
The identifier of the default security group to apply to WorkSpaces when they are created. For more information, see Security Groups for Your WorkSpaces.
sourcepub fn user_enabled_as_local_administrator(&self) -> Option<bool>
pub fn user_enabled_as_local_administrator(&self) -> Option<bool>
Specifies whether WorkSpace users are local administrators on their WorkSpaces.
sourcepub fn enable_maintenance_mode(&self) -> Option<bool>
pub fn enable_maintenance_mode(&self) -> Option<bool>
Specifies whether maintenance mode is enabled for WorkSpaces. For more information, see WorkSpace Maintenance.
sourceimpl DefaultWorkspaceCreationProperties
impl DefaultWorkspaceCreationProperties
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DefaultWorkspaceCreationProperties.