#[non_exhaustive]pub struct FailedCreateStandbyWorkspacesRequest { /* private fields */ }Expand description
Describes the Standby WorkSpace that could not be created.
Implementations
sourceimpl FailedCreateStandbyWorkspacesRequest
impl FailedCreateStandbyWorkspacesRequest
sourcepub fn standby_workspace_request(&self) -> Option<&StandbyWorkspace>
pub fn standby_workspace_request(&self) -> Option<&StandbyWorkspace>
Information about the Standby WorkSpace that could not be created.
sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
The error code that is returned if the Standby WorkSpace could not be created.
sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The text of the error message that is returned if the Standby WorkSpace could not be created.
sourceimpl FailedCreateStandbyWorkspacesRequest
impl FailedCreateStandbyWorkspacesRequest
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture FailedCreateStandbyWorkspacesRequest.