#[non_exhaustive]pub struct FailedWorkspaceChangeRequest { /* private fields */ }Expand description
Describes a WorkSpace that could not be rebooted. (RebootWorkspaces), rebuilt (RebuildWorkspaces), restored (RestoreWorkspace), terminated (TerminateWorkspaces), started (StartWorkspaces), or stopped (StopWorkspaces).
Implementations
sourceimpl FailedWorkspaceChangeRequest
impl FailedWorkspaceChangeRequest
sourcepub fn workspace_id(&self) -> Option<&str>
pub fn workspace_id(&self) -> Option<&str>
The identifier of the WorkSpace.
sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
The error code that is returned if the WorkSpace cannot be rebooted.
sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The text of the error message that is returned if the WorkSpace cannot be rebooted.
sourceimpl FailedWorkspaceChangeRequest
impl FailedWorkspaceChangeRequest
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture FailedWorkspaceChangeRequest.