Struct aws_sdk_workspaces::model::ImagePermission
source · #[non_exhaustive]pub struct ImagePermission { /* private fields */ }Expand description
Describes the Amazon Web Services accounts that have been granted permission to use a shared image. For more information about sharing images, see Share or Unshare a Custom WorkSpaces Image.
Implementations
sourceimpl ImagePermission
impl ImagePermission
The identifier of the Amazon Web Services account that an image has been shared with.
sourceimpl ImagePermission
impl ImagePermission
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ImagePermission.