#[non_exhaustive]pub struct PendingCreateStandbyWorkspacesRequest { /* private fields */ }Expand description
Information about the Standby WorkSpace.
Implementations
sourceimpl PendingCreateStandbyWorkspacesRequest
impl PendingCreateStandbyWorkspacesRequest
sourcepub fn user_name(&self) -> Option<&str>
pub fn user_name(&self) -> Option<&str>
Describes the Standby WorkSpace that was created.
Because this operation is asynchronous, the identifier returned is not immediately available for use with other operations. For example, if you call DescribeWorkspaces before the WorkSpace is created, the information returned can be incomplete.
sourcepub fn directory_id(&self) -> Option<&str>
pub fn directory_id(&self) -> Option<&str>
The identifier of the directory for the Standby WorkSpace.
sourcepub fn state(&self) -> Option<&WorkspaceState>
pub fn state(&self) -> Option<&WorkspaceState>
The operational state of the Standby WorkSpace.
sourcepub fn workspace_id(&self) -> Option<&str>
pub fn workspace_id(&self) -> Option<&str>
The identifier of the Standby WorkSpace.
sourceimpl PendingCreateStandbyWorkspacesRequest
impl PendingCreateStandbyWorkspacesRequest
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture PendingCreateStandbyWorkspacesRequest.