Struct aws_sdk_workspaces::model::SelfservicePermissions
source · #[non_exhaustive]pub struct SelfservicePermissions { /* private fields */ }Expand description
Describes the self-service permissions for a directory. For more information, see Enable Self-Service WorkSpace Management Capabilities for Your Users.
Implementations
sourceimpl SelfservicePermissions
impl SelfservicePermissions
sourcepub fn restart_workspace(&self) -> Option<&ReconnectEnum>
pub fn restart_workspace(&self) -> Option<&ReconnectEnum>
Specifies whether users can restart their WorkSpace.
sourcepub fn increase_volume_size(&self) -> Option<&ReconnectEnum>
pub fn increase_volume_size(&self) -> Option<&ReconnectEnum>
Specifies whether users can increase the volume size of the drives on their WorkSpace.
sourcepub fn change_compute_type(&self) -> Option<&ReconnectEnum>
pub fn change_compute_type(&self) -> Option<&ReconnectEnum>
Specifies whether users can change the compute type (bundle) for their WorkSpace.
sourcepub fn switch_running_mode(&self) -> Option<&ReconnectEnum>
pub fn switch_running_mode(&self) -> Option<&ReconnectEnum>
Specifies whether users can switch the running mode of their WorkSpace.
sourcepub fn rebuild_workspace(&self) -> Option<&ReconnectEnum>
pub fn rebuild_workspace(&self) -> Option<&ReconnectEnum>
Specifies whether users can rebuild the operating system of a WorkSpace to its original state.
sourceimpl SelfservicePermissions
impl SelfservicePermissions
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture SelfservicePermissions.