Struct aws_sdk_workspaces::model::UpdateResult
source · #[non_exhaustive]pub struct UpdateResult { /* private fields */ }Expand description
Describes whether a WorkSpace image needs to be updated with the latest drivers and other components required by Amazon WorkSpaces.
Only Windows 10 WorkSpace images can be programmatically updated at this time.
Implementations
sourceimpl UpdateResult
impl UpdateResult
sourcepub fn update_available(&self) -> Option<bool>
pub fn update_available(&self) -> Option<bool>
Indicates whether updated drivers or other components are available for the specified WorkSpace image.
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of whether updates for the WorkSpace image are pending or available.
sourceimpl UpdateResult
impl UpdateResult
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture UpdateResult.