Struct aws_sdk_workspaces::model::WorkspaceImage
source · #[non_exhaustive]pub struct WorkspaceImage { /* private fields */ }Expand description
Describes a WorkSpace image.
Implementations
sourceimpl WorkspaceImage
impl WorkspaceImage
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the image.
sourcepub fn operating_system(&self) -> Option<&OperatingSystem>
pub fn operating_system(&self) -> Option<&OperatingSystem>
The operating system that the image is running.
sourcepub fn state(&self) -> Option<&WorkspaceImageState>
pub fn state(&self) -> Option<&WorkspaceImageState>
The status of the image.
sourcepub fn required_tenancy(&self) -> Option<&WorkspaceImageRequiredTenancy>
pub fn required_tenancy(&self) -> Option<&WorkspaceImageRequiredTenancy>
Specifies whether the image is running on dedicated hardware. When Bring Your Own License (BYOL) is enabled, this value is set to DEDICATED. For more information, see Bring Your Own Windows Desktop Images.
sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
The error code that is returned for the image.
sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The text of the error message that is returned for the image.
sourcepub fn created(&self) -> Option<&DateTime>
pub fn created(&self) -> Option<&DateTime>
The date when the image was created. If the image has been shared, the Amazon Web Services account that the image has been shared with sees the original creation date of the image.
sourcepub fn owner_account_id(&self) -> Option<&str>
pub fn owner_account_id(&self) -> Option<&str>
The identifier of the Amazon Web Services account that owns the image.
sourcepub fn updates(&self) -> Option<&UpdateResult>
pub fn updates(&self) -> Option<&UpdateResult>
The updates (if any) that are available for the specified image.
sourceimpl WorkspaceImage
impl WorkspaceImage
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture WorkspaceImage.