Struct aws_sdk_workspaces::model::update_result::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for UpdateResult.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn update_available(self, input: bool) -> Self
pub fn update_available(self, input: bool) -> Self
Indicates whether updated drivers or other components are available for the specified WorkSpace image.
sourcepub fn set_update_available(self, input: Option<bool>) -> Self
pub fn set_update_available(self, input: Option<bool>) -> Self
Indicates whether updated drivers or other components are available for the specified WorkSpace image.
sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of whether updates for the WorkSpace image are pending or available.
sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of whether updates for the WorkSpace image are pending or available.
sourcepub fn build(self) -> UpdateResult
pub fn build(self) -> UpdateResult
Consumes the builder and constructs a UpdateResult.