Struct aws_sdk_workspaces::output::create_workspaces_output::Builder
source · [−]#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for CreateWorkspacesOutput
Implementations
sourceimpl Builder
impl Builder
sourcepub fn failed_requests(self, input: FailedCreateWorkspaceRequest) -> Self
pub fn failed_requests(self, input: FailedCreateWorkspaceRequest) -> Self
Appends an item to failed_requests.
To override the contents of this collection use set_failed_requests.
Information about the WorkSpaces that could not be created.
sourcepub fn set_failed_requests(
self,
input: Option<Vec<FailedCreateWorkspaceRequest>>
) -> Self
pub fn set_failed_requests(
self,
input: Option<Vec<FailedCreateWorkspaceRequest>>
) -> Self
Information about the WorkSpaces that could not be created.
sourcepub fn pending_requests(self, input: Workspace) -> Self
pub fn pending_requests(self, input: Workspace) -> Self
Appends an item to pending_requests.
To override the contents of this collection use set_pending_requests.
Information about the WorkSpaces that were created.
Because this operation is asynchronous, the identifier returned is not immediately available for use with other operations. For example, if you call DescribeWorkspaces before the WorkSpace is created, the information returned can be incomplete.
sourcepub fn set_pending_requests(self, input: Option<Vec<Workspace>>) -> Self
pub fn set_pending_requests(self, input: Option<Vec<Workspace>>) -> Self
Information about the WorkSpaces that were created.
Because this operation is asynchronous, the identifier returned is not immediately available for use with other operations. For example, if you call DescribeWorkspaces before the WorkSpace is created, the information returned can be incomplete.
sourcepub fn build(self) -> CreateWorkspacesOutput
pub fn build(self) -> CreateWorkspacesOutput
Consumes the builder and constructs a CreateWorkspacesOutput