#[non_exhaustive]
pub struct DescribeAccountOutput { /* private fields */ }

Implementations

The status of BYOL (whether BYOL is enabled or disabled).

The IP address range, specified as an IPv4 CIDR block, used for the management network interface.

The management network interface is connected to a secure Amazon WorkSpaces management network. It is used for interactive streaming of the WorkSpace desktop to Amazon WorkSpaces clients, and to allow Amazon WorkSpaces to manage the WorkSpace.

Creates a new builder-style object to manufacture DescribeAccountOutput.