#[non_exhaustive]pub struct DescribeConnectionAliasesOutput {
pub connection_aliases: Option<Vec<ConnectionAlias>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_aliases: Option<Vec<ConnectionAlias>>Information about the specified connection aliases.
next_token: Option<String>The token to use to retrieve the next page of results. This value is null when there are no more results to return.
Implementations
sourceimpl DescribeConnectionAliasesOutput
impl DescribeConnectionAliasesOutput
sourcepub fn connection_aliases(&self) -> Option<&[ConnectionAlias]>
pub fn connection_aliases(&self) -> Option<&[ConnectionAlias]>
Information about the specified connection aliases.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token to use to retrieve the next page of results. This value is null when there are no more results to return.
sourceimpl DescribeConnectionAliasesOutput
impl DescribeConnectionAliasesOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeConnectionAliasesOutput