#[non_exhaustive]pub struct DescribeWorkspaceSnapshotsOutput { /* private fields */ }Implementations
sourceimpl DescribeWorkspaceSnapshotsOutput
impl DescribeWorkspaceSnapshotsOutput
sourcepub fn rebuild_snapshots(&self) -> Option<&[Snapshot]>
pub fn rebuild_snapshots(&self) -> Option<&[Snapshot]>
Information about the snapshots that can be used to rebuild a WorkSpace. These snapshots include the user volume.
sourcepub fn restore_snapshots(&self) -> Option<&[Snapshot]>
pub fn restore_snapshots(&self) -> Option<&[Snapshot]>
Information about the snapshots that can be used to restore a WorkSpace. These snapshots include both the root volume and the user volume.
sourceimpl DescribeWorkspaceSnapshotsOutput
impl DescribeWorkspaceSnapshotsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeWorkspaceSnapshotsOutput.