Enum aws_sdk_workspaces::error::RegisterWorkspaceDirectoryErrorKind [−][src]
#[non_exhaustive]
pub enum RegisterWorkspaceDirectoryErrorKind {
AccessDeniedException(AccessDeniedException),
InvalidParameterValuesException(InvalidParameterValuesException),
InvalidResourceStateException(InvalidResourceStateException),
OperationNotSupportedException(OperationNotSupportedException),
ResourceLimitExceededException(ResourceLimitExceededException),
ResourceNotFoundException(ResourceNotFoundException),
UnsupportedNetworkConfigurationException(UnsupportedNetworkConfigurationException),
WorkspacesDefaultRoleNotFoundException(WorkspacesDefaultRoleNotFoundException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the RegisterWorkspaceDirectory operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Tuple Fields
The user is not authorized to access a resource.
InvalidParameterValuesException(InvalidParameterValuesException)
Tuple Fields
One or more parameter values are not valid.
InvalidResourceStateException(InvalidResourceStateException)
Tuple Fields
The state of the resource is not valid for this operation.
OperationNotSupportedException(OperationNotSupportedException)
Tuple Fields
This operation is not supported.
ResourceLimitExceededException(ResourceLimitExceededException)
Tuple Fields
Your resource limits have been exceeded.
ResourceNotFoundException(ResourceNotFoundException)
Tuple Fields
The resource could not be found.
UnsupportedNetworkConfigurationException(UnsupportedNetworkConfigurationException)
Tuple Fields
The configuration of this network is not supported for this operation, or your network configuration conflicts with the Amazon WorkSpaces management network IP range. For more information, see Configure a VPC for Amazon WorkSpaces.
WorkspacesDefaultRoleNotFoundException(WorkspacesDefaultRoleNotFoundException)
Tuple Fields
The workspaces_DefaultRole role could not be found. If this is the first time you are registering a directory, you will need to create the workspaces_DefaultRole role before you can register a directory. For more information, see Creating the workspaces_DefaultRole Role.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code