Enum aws_sdk_workspaces::error::RegisterWorkspaceDirectoryErrorKind[][src]

#[non_exhaustive]
pub enum RegisterWorkspaceDirectoryErrorKind {
    AccessDeniedException(AccessDeniedException),
    InvalidParameterValuesException(InvalidParameterValuesException),
    InvalidResourceStateException(InvalidResourceStateException),
    OperationNotSupportedException(OperationNotSupportedException),
    ResourceLimitExceededException(ResourceLimitExceededException),
    ResourceNotFoundException(ResourceNotFoundException),
    UnsupportedNetworkConfigurationException(UnsupportedNetworkConfigurationException),
    WorkspacesDefaultRoleNotFoundException(WorkspacesDefaultRoleNotFoundException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the RegisterWorkspaceDirectory operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AccessDeniedException(AccessDeniedException)

The user is not authorized to access a resource.

Tuple Fields of AccessDeniedException

0: AccessDeniedException
InvalidParameterValuesException(InvalidParameterValuesException)

One or more parameter values are not valid.

Tuple Fields of InvalidParameterValuesException

0: InvalidParameterValuesException
InvalidResourceStateException(InvalidResourceStateException)

The state of the resource is not valid for this operation.

Tuple Fields of InvalidResourceStateException

0: InvalidResourceStateException
OperationNotSupportedException(OperationNotSupportedException)

This operation is not supported.

Tuple Fields of OperationNotSupportedException

0: OperationNotSupportedException
ResourceLimitExceededException(ResourceLimitExceededException)

Your resource limits have been exceeded.

Tuple Fields of ResourceLimitExceededException

0: ResourceLimitExceededException
ResourceNotFoundException(ResourceNotFoundException)

The resource could not be found.

Tuple Fields of ResourceNotFoundException

0: ResourceNotFoundException
UnsupportedNetworkConfigurationException(UnsupportedNetworkConfigurationException)

The configuration of this network is not supported for this operation, or your network configuration conflicts with the Amazon WorkSpaces management network IP range. For more information, see Configure a VPC for Amazon WorkSpaces.

Tuple Fields of UnsupportedNetworkConfigurationException

0: UnsupportedNetworkConfigurationException
WorkspacesDefaultRoleNotFoundException(WorkspacesDefaultRoleNotFoundException)

The workspaces_DefaultRole role could not be found. If this is the first time you are registering a directory, you will need to create the workspaces_DefaultRole role before you can register a directory. For more information, see Creating the workspaces_DefaultRole Role.

Tuple Fields of WorkspacesDefaultRoleNotFoundException

0: WorkspacesDefaultRoleNotFoundException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>