Struct aws_sdk_workspaces::input::describe_ip_groups_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DescribeIpGroupsInput
Implementations
Appends an item to group_ids.
To override the contents of this collection use set_group_ids.
The identifiers of one or more IP access control groups.
The identifiers of one or more IP access control groups.
If you received a NextToken from a previous call that was paginated,
provide this token to receive the next set of results.
If you received a NextToken from a previous call that was paginated,
provide this token to receive the next set of results.
The maximum number of items to return.
The maximum number of items to return.
Consumes the builder and constructs a DescribeIpGroupsInput