Struct aws_sdk_workspaces::input::RegisterWorkspaceDirectoryInput [−][src]
#[non_exhaustive]pub struct RegisterWorkspaceDirectoryInput {
pub directory_id: Option<String>,
pub subnet_ids: Option<Vec<String>>,
pub enable_work_docs: Option<bool>,
pub enable_self_service: Option<bool>,
pub tenancy: Option<Tenancy>,
pub tags: Option<Vec<Tag>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.directory_id: Option<String>The identifier of the directory. You cannot register a directory if it does not have a status of Active. If the directory does not have a status of Active, you will receive an InvalidResourceStateException error. If you have already registered the maximum number of directories that you can register with Amazon WorkSpaces, you will receive a ResourceLimitExceededException error. Deregister directories that you are not using for WorkSpaces, and try again.
subnet_ids: Option<Vec<String>>The identifiers of the subnets for your virtual private cloud (VPC). Make sure that the subnets are in supported Availability Zones. The subnets must also be in separate Availability Zones. If these conditions are not met, you will receive an OperationNotSupportedException error.
enable_work_docs: Option<bool>Indicates whether Amazon WorkDocs is enabled or disabled. If you have enabled this parameter and
WorkDocs is not available in the Region, you will receive an OperationNotSupportedException error. Set
EnableWorkDocs to disabled, and try again.
enable_self_service: Option<bool>Indicates whether self-service capabilities are enabled or disabled.
tenancy: Option<Tenancy>Indicates whether your WorkSpace directory is dedicated or shared. To use Bring Your Own
License (BYOL) images, this value must be set to DEDICATED and your Amazon Web Services account must be
enabled for BYOL. If your account has not been enabled for BYOL, you will receive an
InvalidParameterValuesException error. For more information about BYOL images, see
Bring Your Own Windows Desktop Images.
The tags associated with the directory.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<RegisterWorkspaceDirectory, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<RegisterWorkspaceDirectory, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<RegisterWorkspaceDirectory>
Creates a new builder-style object to manufacture RegisterWorkspaceDirectoryInput