Struct aws_sdk_workspaces::output::create_workspaces_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateWorkspacesOutput
Implementations
Appends an item to failed_requests.
To override the contents of this collection use set_failed_requests.
Information about the WorkSpaces that could not be created.
Information about the WorkSpaces that could not be created.
Appends an item to pending_requests.
To override the contents of this collection use set_pending_requests.
Information about the WorkSpaces that were created.
Because this operation is asynchronous, the identifier returned is not immediately available for use with other operations. For example, if you call DescribeWorkspaces before the WorkSpace is created, the information returned can be incomplete.
Information about the WorkSpaces that were created.
Because this operation is asynchronous, the identifier returned is not immediately available for use with other operations. For example, if you call DescribeWorkspaces before the WorkSpace is created, the information returned can be incomplete.
Consumes the builder and constructs a CreateWorkspacesOutput