Struct aws_sdk_workspaces::output::DescribeAccountOutput
source · #[non_exhaustive]pub struct DescribeAccountOutput { /* private fields */ }Implementations
sourceimpl DescribeAccountOutput
impl DescribeAccountOutput
sourcepub fn dedicated_tenancy_support(
&self
) -> Option<&DedicatedTenancySupportResultEnum>
pub fn dedicated_tenancy_support(
&self
) -> Option<&DedicatedTenancySupportResultEnum>
The status of BYOL (whether BYOL is enabled or disabled).
sourcepub fn dedicated_tenancy_management_cidr_range(&self) -> Option<&str>
pub fn dedicated_tenancy_management_cidr_range(&self) -> Option<&str>
The IP address range, specified as an IPv4 CIDR block, used for the management network interface.
The management network interface is connected to a secure Amazon WorkSpaces management network. It is used for interactive streaming of the WorkSpace desktop to Amazon WorkSpaces clients, and to allow Amazon WorkSpaces to manage the WorkSpace.
sourceimpl DescribeAccountOutput
impl DescribeAccountOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeAccountOutput.